@@ -15,12 +15,12 @@ class RawResponse:
         self._status = status
 
     @property
-    def response(self):
-        return self._response
+    def body(self):
+        return self._body
 
-    @response.setter
-    def response(self, response):
-        self._response = response
+    @body.setter
+    def body(self, response):
+        self._body = response
 
 class TimeSeries:
     '''
@@ -44,17 +44,39 @@ class TimeSeries:
     def data_date(self):
         return self._data_date
     
-    def get_metering_data(self, hour):
+    def get_metering_data(self, index):
         '''
-        Get metering data for a single hour.
-        hour=1: data between 00.00 and 01.00.
-        hour=4: data between 03.00 and 04.00.
+        Get metering data for a single hour or month.
+        index=1: data between 00.00 and 01.00 if TimeSeries contains day data, or January if TimeSeries contains month data.
+        index=4: data between 03.00 and 04.00 if TimeSeries contains day data, or April if TimeSeries contains month data.
         '''
-        return self._metering_data[hour-1]
+        return self._metering_data[index-1]
 
     def get_total_metering_data(self):
         total = 0
         for v in self._metering_data:
             total += v
 
-        return total
\ No newline at end of file
+        return total
+
+class Charges:
+    '''
+    Class representing parsed charges data.
+    '''
+    def __init__(self, status, charges, detailed_status=None):
+        self._status = status
+        self._charges = charges
+        self._detailed_status = detailed_status
+
+    @property
+    def status(self):
+        return self._status
+
+    @property
+    def detailed_status(self):
+        return self._detailed_status
+    
+    @property
+    def charges(self):
+        return self._charges
+    
\ No newline at end of file
